@@ -50,6 +50,7 @@ class Store(object):
 		self._callback_user_tools_changed = set()
 		self._callback_queries_changed = set()
 		self._callback_settings_changed = set()
+		self._callback_error = set()
 		
 	def _init_min_free_id(self) -> None:
 		
@@ -216,6 +217,16 @@ class Store(object):
 		for func in self._callback_settings_changed:
 			func()
 	
+	def set_callback_error(self, func):
+		
+		self._callback_error.add(func)
+	
+	def callback_error(self, message):
+		
+		print(message)
+		for func in self._callback_error:
+			func(message)
+	
 	
 	# ---- General
 	# ------------------------------------------------------------------------
@@ -1000,7 +1011,6 @@ class Store(object):
 		if progress is not None:
 			progress.update_state(value = 0, maximum = cmax)
 		for obj_id0 in objects0:
-#			print("\r%d/%d           " % (cnt, cmax), end = "") # DEBUG
 			if (progress is not None) and (cnt % 100 == 0):
 				if progress.cancel_pressed():
 					return []
@@ -1065,6 +1075,18 @@ class Store(object):
 				queue.add(orig2.id)
 				done.add(orig2.id)
 		
+		# add within-class relations
+		for orig_id in obj_lookup:
+			orig = self.get_object(orig_id)
+			classes = set([cls.name for cls in orig.get_classes()])
+			for orig2, label in orig.get_relations():
+				if orig2.id not in obj_lookup:
+					continue
+				if not classes.intersection([cls.name for cls in orig2.get_classes()]):
+					continue
+				weight = orig.get_relation_weight(orig2, label)
+				obj_lookup[orig_id].add_relation(obj_lookup[orig2.id], label, weight = weight)
+		
 		# collect descriptor names
 		for orig_id in obj_lookup:
 			for descr in self.get_object(orig_id).get_descriptors():
